'''
Tests for NFV TST 010 attachments generation script
'''

import create_sols as crs


def test_parse_tag_from_log():
    '''Test usage of parse_tag_from_log'''

    with_tag = "231f303 (HEAD, tag: 2.7.1.0.0.2, origin/2.7.1-dev) updated indexes"
    without_tag = "023ca44 (mybranch) Merge branch '2.7.1-dev-SOL002-branch' into '2.7.1-dev'"

    assert crs.parse_tag_from_log(with_tag) == "2.7.1.0.0.2"
    assert crs.parse_tag_from_log(without_tag) is None


def test_parse_commit_from_log():
    '''Test usage of parse_tag_from_log'''

    with_tag = "231f303 (HEAD, tag: 2.7.1.0.0.2, origin/2.7.1-dev) updated indexes"
    without_tag = "023ca44 (mybranch) Merge branch '2.7.1-dev-SOL002-branch' into '2.7.1-dev'"
    wrong = ""

    assert crs.parse_commit_from_log(with_tag) == "231f303"
    assert crs.parse_commit_from_log(without_tag) == "023ca44"
    assert crs.parse_commit_from_log(wrong) is None


def test_get_git_reference():

    comm, reftype, branch = crs.get_git_reference('..')

    assert comm is not None
    assert isinstance(comm, str)

def test_parse_branch_from_log():
    '''Test usage of parse_branch_from_log'''

    with_branch = "231f303 (HEAD, tag: 2.7.1.0.0.2, origin/2.7.1-dev) updated indexes"
    with_master = "023ca44 (origin/master) Merge branch '2.7.1-dev-SOL002-branch' into '2.7.1-dev'"
    without_branch = "023ca44 (noBranch) Merge branch '2.7.1-dev-SOL002-branch' into '2.7.1-dev'"

    assert crs.parse_branch_from_log(with_branch) == "2.7.1-dev"
    assert crs.parse_branch_from_log(with_master) == "master"
    assert crs.parse_branch_from_log(without_branch) is None
